********************************
*Code produced by Mark Williams*
*	mark.williams@qmul.ac.uk  *
********************************

set more off
global dir "[insert directory where data are stored here]"
global output "[insert place where output is to be saved here]"

*Data can be downloaded from https://beta.ukdataservice.ac.uk/datacatalogue/studies/study?id=8589.

*********************************
*			Introduction		*
*********************************


*********************************
*			Chapter 2			*
*********************************

*Work orientations
use "$dir\ses2017.dta", clear

*Overall 
mean revforien* [aw=weightall] if year==2017
est sto mwo
coefplot (mwo, msymbol(Oh)), sort(,desc) 
graph export "$output\wo.png", replace

*By year
mean revforien* [aw=weightall] if year==1992
est sto mwo_1
mean revforien* [aw=weightall] if year==2006
est sto mwo_2
mean revforien* [aw=weightall] if year==2012
est sto mwo_3
mean revforien* [aw=weightall] if year==2017
est sto mwo_4
coefplot (mwo_1, label("1992") msymbol(Oh)) (mwo_2, label("2006") msymbol(Th)) ///
	(mwo_3, label("2012") msymbol(Sh)) (mwo_4, label("2017") msymbol(X)), sort(,desc) ///
	title("By year") legend(pos(6))
graph save "$output\woXyear.gph", replace

*By class
mean revforien* [aw=weightall] if year==2017 & class3==1
est sto mwo_1
mean revforien* [aw=weightall] if year==2017 & class3==2
est sto mwo_2
mean revforien* [aw=weightall] if year==2017 & class3==3
est sto mwo_3
coefplot (mwo_1, label("Managerial & professional") msymbol(Oh)) (mwo_2, label("Intermediate occupations") msymbol(Th)) ///
	(mwo_3, label("Routine & manual occupations") msymbol(Sh)), sort(,desc) title("By class") legend(pos(6))
graph save "$output\woXclass3.gph", replace

*By hours
mean revforien* [aw=weightall] if year==2017 & hourscat==1
est sto mwo_1
mean revforien* [aw=weightall] if year==2017 & hourscat==2
est sto mwo_2
mean revforien* [aw=weightall] if year==2017 & hourscat==3
est sto mwo_3
coefplot (mwo_1, label("1-34") msymbol(Oh)) (mwo_2, label("35-44") msymbol(Th)) ///
	(mwo_3, label("45+") msymbol(Sh)), sort(,desc) title("By hours") legend(pos(6))
graph save "$output\woXhours.gph", replace

*By age
mean revforien* [aw=weightall] if year==2017 & agecat==1
est sto mwo_1
mean revforien* [aw=weightall] if year==2017 & agecat==2
est sto mwo_2
mean revforien* [aw=weightall] if year==2017 & agecat==3
est sto mwo_3
coefplot (mwo_1, label("20-34") msymbol(Oh)) (mwo_2, label("35-49") msymbol(Th)) ///
	(mwo_3, label("50+") msymbol(Sh)), sort(,desc) title("By age") legend(pos(6))
graph save "$output\woXage.gph", replace

*By gender
mean revforien* [aw=weightall] if year==2017 & sex==0
est sto mwo_1
mean revforien* [aw=weightall] if year==2017 & sex==1
est sto mwo_2
coefplot (mwo_1, label("Men") msymbol(Oh)) (mwo_2, label("Women") msymbol(Th)), ///
	sort(,desc) title("By gender") legend(pos(6))
graph save "$output\woXgend.gph", replace

*By ethnicity
mean revforien* [aw=weightall] if year==2017 & ethnic==0
est sto mwo_1
mean revforien* [aw=weightall] if year==2017 & ethnic==1
est sto mwo_2
coefplot (mwo_1, label("White") msymbol(Oh)) (mwo_2, label("Non-white") msymbol(Th)), ///
	sort(,desc) title("By ethnicity") legend(pos(6))
graph save "$output\woXeth.gph", replace

*Graph
graph combine "$output\woXyear.gph" "$output\woXclass3.gph" "$output\woXhours.gph", ///
	row(2) col(3) xcommon ycommon altshrink
graph export "$output\woXgroup1.png", replace

graph combine "$output\woXage.gph" "$output\woXgend.gph" "$output\woXeth.gph", ////
	row(2) col(3) xcommon ycommon altshrink
graph export "$output\woXgroup2.png", replace


*Meaning of overall satisfaction
use "$dir\ses2017.dta", clear

*All
reg satis_ses revksat1-revksat14 i.year [aw=weightall]
est sto js_1
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]
est sto js_2
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry revforien* [aw=weightall]
est sto js_3
coefplot (js_1, label("No controls") msymbol(Oh)) (js_2, label("Controls") msymbol(Th)) ///
	(js_3, label("Controls + orientations") msymbol(Sh)), keep(revksat1 revksat2 ///
	revksat3 revksat4 revksat5 revksat6 revksat7 revksat8 revksat9 revksat10 revksat11 ///
	revksat12 revksat13 revksat14) sort(, descending) legend(pos(6)) xline(0.0)
graph export "$output\jobsat.png", replace

*Year	
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]  if year==2006
est sto js_1			
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]  if year==2012
est sto js_2
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]  if year==2017
est sto js_3
coefplot (js_1, label("2006") msymbol(Oh)) (js_2, label("2012") msymbol(Th)) ///
	(js_3, label("2017") msymbol(Sh)), keep(revksat1 revksat2 ///
	revksat3 revksat4 revksat5 revksat6 revksat7 revksat8 revksat9 revksat10 revksat11 ///
	revksat12 revksat13 revksat14)sort(,desc) title("By year") legend(pos(6)) xline(0.0)
graph save "$output\jobsatXyear.gph", replace	

*class3 
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if class3==1
est sto js_1
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if class3==2
est sto js_2
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if class3==3
est sto js_3
coefplot (js_1, label("Managerial & professional") msymbol(Oh)) (js_2, label("Intermediate occupations") msymbol(Th)) ///
	(js_3, label("Routine & manual occupations") msymbol(Sh)), keep(revksat1 revksat2 ///
	revksat3 revksat4 revksat5 revksat6 revksat7 revksat8 revksat9 revksat10 revksat11 ///
	revksat12 revksat13 revksat14) sort(,desc) title("By class") legend(pos(6)) xline(0.0)
graph save "$output\jobsatXclass3.gph", replace

*Hours
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if hourscat==1
est sto js_1
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if hourscat==2
est sto js_2
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if hourscat==3
est sto js_3
coefplot (js_1, label("1-34") msymbol(Oh)) (js_2, label("35-44") msymbol(Th)) ///
	(js_3, label("45+") msymbol(Sh)), keep(revksat1 revksat2 ///
	revksat3 revksat4 revksat5 revksat6 revksat7 revksat8 revksat9 revksat10 revksat11 ///
	revksat12 revksat13 revksat14) sort(,desc) title("By hours") legend(pos(6)) xline(0.0)
graph save "$output\jobsatXhours.gph", replace

*Age
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if agecat==1
est sto js_1		
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if agecat==2
est sto js_2				
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if agecat==3
est sto js_3
coefplot (js_1, label("20-34") msymbol(Oh)) (js_2, label("35-49") msymbol(Th)) ///
	(js_3, label("50+") msymbol(Sh)), keep(revksat1 revksat2 ///
	revksat3 revksat4 revksat5 revksat6 revksat7 revksat8 revksat9 revksat10 revksat11 ///
	revksat12 revksat13 revksat14) sort(,desc) title("By age") legend(pos(6)) xline(0.0) 
graph save "$output\jobsatXage.gph", replace

*Gender
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]  if sex==1
est sto js_1
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]  if sex==0
est sto js_2

coefplot (js_1, label("Men") msymbol(Oh)) (js_2, label("Women") msymbol(Th)), keep(revksat1 revksat2 ///
	revksat3 revksat4 revksat5 revksat6 revksat7 revksat8 revksat9 revksat10 revksat11 ///
	revksat12 revksat13 revksat14) sort(, descending) title("By gender") legend(pos(6)) xline(0.0)
graph save "$output\jobsatXgend.gph", replace

*Ethnicity
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]  if ethnic==0
est sto js_1
reg satis_ses revksat1-revksat14 i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]  if ethnic==1
est sto js_2
coefplot (js_1, label("White") msymbol(Oh)) (js_2, label("Non-white")  msymbol(Th)), keep(revksat1 revksat2 ///
	revksat3 revksat4 revksat5 revksat6 revksat7 revksat8 revksat9 revksat10 revksat11 ///
	revksat12 revksat13 revksat14) sort(, descending) title("By ethnicity") legend(pos(6)) xline(0.0)
graph save "$output\jobsatXeth.gph", replace

*Graph
graph combine "$output\jobsatXyear.gph" "$output\jobsatXclass3.gph" "$output\jobsatXhours.gph", ///
	row(2) col(3) xcommon ycommon altshrink
graph export "$output\jobsatXgroup1.png", replace

graph combine "$output\jobsatXage.gph" "$output\jobsatXgend.gph" "$output\jobsatXeth.gph", ////
	row(2) col(3) xcommon ycommon altshrink
graph export "$output\jobsatXgroup2.png", replace



*Predictive effects of job quality on overall job satisfaction
use "$dir\ses2017.dta", clear

drop sample std_*

reg satis_ses lnhourpay_ses security_ses learning_ses useskills_ses variety_ses discret_ses ///
	demands_ses wlb_ses rep_ses i.year [aw=weightall]
gen sample=e(sample)
foreach var of varlist lnhourpay_ses security_ses learning_ses useskills_ses variety_ses discret_ses ///
	demands_ses wlb_ses rep_ses {
center `var' [aw=weightall], gen(std_`var') standardize
}

label var std_lnhourpay "Hourly pay"
label var std_security_ses "Job security"
label var std_learning_ses "Continuous learning"
label var std_useskills_ses "Skill-use opportunities"
label var std_variety_ses "Task variety"
label var std_discret_ses "Task discretion"
label var std_demands_ses  "Job demands"
label var std_wlb_ses "Work time control"
label var std_rep_ses "Participation opportunities"

*All
reg satis_ses std_* i.year [aw=weightall]
est sto m1
reg satis_ses std_* i.year i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]
est sto m2
reg satis_ses std_* i.year i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry revforient* [aw=weightall]
est sto m3
coefplot (m1, label("No controls") msymbol(Oh)) (m2,  label("Controls") msymbol(Th)) ///
(m3,  label("Controls + orientations") msymbol(Sh)), sort(,desc) ///
keep(std_*) legend(pos(6)) xline(0.0) 
graph export "$output\predjs.png", replace

*Year	
reg satis_ses std_* i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]  if year==2006
est sto predjs_1		
reg satis_ses std_* i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]  if year==2012
est sto predjs_2			
reg satis_ses std_* i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]  if year==2017
est sto predjs_3
coefplot (predjs_1, label("2006") msymbol(Oh)) (predjs_2, label("2012") msymbol(Th)) ///
	(predjs_3, label("2017") msymbol(Sh)), keep(std_*) ///
	sort(,desc) title("By year") legend(pos(6)) xline(0.0)
graph save "$output\predjsXyear.gph", replace	

*class 
reg satis_ses std_* i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if class3==1
est sto predjs_1
reg satis_ses std_* i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if class3==2
est sto predjs_2
reg satis_ses std_* i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if class3==3
est sto predjs_3
coefplot (predjs_1, label("Managerial & professional") msymbol(Oh)) (predjs_2, label("Intermediate occupations") msymbol(Th)) ///
	(predjs_3, label("Routine & manual occupations") msymbol(Sh)), keep(std_*) ///
	 sort(,desc) title("By class") legend(pos(6)) xline(0.0)
graph save "$output\predjsXclass3.gph", replace

*Hours
reg satis_ses std_* i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if hourscat==1
est sto predjs_1
reg satis_ses std_* i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if hourscat==2
est sto predjs_2
reg satis_ses std_* i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if hourscat==3
est sto predjs_3
coefplot (predjs_1, label("1-34") msymbol(Oh)) (predjs_2, label("35-44") msymbol(Th)) ///
	(predjs_3, label("45+") msymbol(Sh)), keep(std_*) ///
	 sort(,desc) title("By hours") legend(pos(6)) xline(0.0)
graph save "$output\predjsXhours.gph", replace

*Age
reg satis_ses std_* i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if agecat==1
est sto predjs_1		
reg satis_ses std_* i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if agecat==2
est sto predjs_2				
reg satis_ses std_* i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall] if agecat==3
est sto predjs_3
coefplot (predjs_1, label("20-34") msymbol(Oh)) (predjs_2, label("35-49") msymbol(Th)) ///
	(predjs_3, label("50+") msymbol(Sh)), keep(std_*) ///
	 sort(,desc) title("By age") legend(pos(6)) xline(0.0)
graph save "$output\predjsXage.gph", replace

*Gender
reg satis_ses std_* i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]  if sex==1
est sto predjs_1
reg satis_ses std_* i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]  if sex==0
est sto predjs_2
coefplot (predjs_1, label("Men") msymbol(Oh)) (predjs_2, label("Women") msymbol(Th)), keep(std_*) ///
	 sort(, descending) title("By gender") legend(pos(6)) xline(0.0)
graph save "$output\predjsXgend.gph", replace

*Ethnicity
reg satis_ses std_* i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]  if ethnic==0
est sto predjs_1
reg satis_ses std_* i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]  if ethnic==1
est sto predjs_2
coefplot (predjs_1, label("White") msymbol(Oh)) (predjs_2, label("Non-white")  msymbol(Th)), keep(std_*) ///
	 sort(, descending) title("By ethnicity") legend(pos(6)) xline(0.0)
graph save "$output\predjsXeth.gph", replace

*Graph
graph combine "$output\predjsXyear.gph" "$output\predjsXclass3.gph" "$output\predjsXhours.gph", ///
	row(2) col(3) xcommon ycommon altshrink
graph export "$output\predjsXgroup1.png", replace

graph combine "$output\predjsXage.gph" "$output\predjsXgend.gph" "$output\predjsXeth.gph", ////
	row(2) col(3) xcommon ycommon altshrink
graph export "$output\predjsXgroup2.png", replace


*Good Work Index of Job Quality (GWI-JQ)
use "$dir\ses2017.dta", clear

drop sample jq nwjq *pc *terc *quart *quint *dec std_* *_sespc

reg satis_ses lnhourpay_ses security_ses learning_ses useskills_ses ///
	variety_ses demands_ses discret_ses wlb_ses rep_ses ///
	i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp union_wp i.wpsize2 i.industry [aw=weightall], absorb(rcsoc2000)
gen sample=e(sample)
	
areg satis_ses lnhourpay_ses security_ses learning_ses useskills_ses ///
	variety_ses demands_ses discret_ses wlb_ses rep_ses ///
	i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp union_wp i.wpsize2 i.industry [aw=weightall], absorb(rcsoc2000)
mat b=e(b)
mat b=b[1,1..9]
mat score jq=b if sample==1
mat c=b[1,2..9]
mat score nwjq=c if sample==1	

foreach var of varlist lnhourpay_ses security_ses learning_ses useskills_ses ///
	variety_ses demands_ses discret_ses wlb_ses rep_ses jq {
center `var' [aw=weightall] if sample==1, gen(std_`var') standardize
xtile `var'pc = `var' [aw=weightall] if sample==1, nq(100)
xtile `var'dec = `var' [aw=weightall] if sample==1, nq(10)
xtile `var'terc = `var' [aw=weightall] if sample==1, nq(3)
xtile `var'quart = `var' [aw=weightall] if sample==1, nq(4)
xtile `var'quint = `var' [aw=weightall] if sample==1, nq(5)
}

save, replace

*Characteristics and JQ
use "$dir\ses2017.dta", clear

reg jqpc ///
	i.year i.sex i.ageband i.ethnic i.kids i.region3 i.degree i.pt i.mansup i.selfemp i.temp i.union_wp i.wpsize2 i.industry i.class3
est sto reg
margins i.class3 i.industry i.pt i.temp i.mansup i.selfemp i.wpsize2 i.union_wp, post
est sto m1
est rest reg
margins i.degree i.ageband i.sex i.ethnic i.kids i.region3, post
est sto m2

coefplot m1, ylabel(1 "Managerial & professional" 2 "Intermediate occupations" 3 "Routine & manual occupations" 4 "Industry" ///
	5 "Consumer services" 6 "Financial and business services" 7 "Public services" 8 "Full-time" 9 "Part-time" ///
	10 "Permanent contract" 11 "Temporary contract" 12 "Non-manager/supervisor" 13 "Manager/superisor" ///
	14 "Employee" 15 "Self-employed" 16 "1-25 employees" 17 "25-499 employees" ///
	18 "500+ employees" 19 "Non-union" 20 "Workplace union")
graph export "$output\gwi_predictors1.png", replace

coefplot m2, ylabel(1 "Non-graduate" 2 "Graduate" 3 "Age <25" 4 "Age 25-34" 5 "Age 35-44" 6 "Age 45-54" ///
	7 "Age 55+" 8 "Male" 9 "Female" 10 "White ethnicity" 11 "Non-white ethnicity" ///
	12 "Childless" 13 "Has children" 14 "Northern England" 15 "Midlands" ///
	16 "Southern and Eastern England" 17 "London" 18 "Wales" 19 "Scotland")
graph export "$output\gwi_predictors2.png", replace

*JQ and affect
reg	pos i.jqdec i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]
margins jqdec, post
est sto m1

reg neg i.jqdec i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]
margins jqdec, post
est sto m2

coefplot (m1, label("Positive affect") msymbol(Oh)) (m2, label("Negative affect") msymbol(Th)) ///
	, sort(,desc) legend(pos(6)) xline(0.0) ylabel(10 "1" 9 "2" 8 "3" 7 "4" ///
	6 "5" 5 "6" 4 "7" 3 "8" 2 "9" 1 "10")
graph export "$output\gwi_affect.png", replace

*JQ and job attiudes	
reg	commitment i.jqdec i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]
margins jqdec, post
est sto m1

reg	diseff i.jqdec i.year sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]
margins jqdec, post
est sto m2

coefplot (m1, label("Commitment") msymbol(Oh)) (m2, label("Discretionary effort") msymbol(Th)) ///
	, sort(,desc) legend(pos(6)) xline(0.0) ylabel(10 "1" 9 "2" 8 "3" 7 "4" ///
	6 "5" 5 "6" 4 "7" 3 "8" 2 "9" 1 "10")
graph export "$output\gwi_attitudes.png", replace

*Life satisfaction
reg revklifesat i.jqdec sex i.ageband ethnic kids i.region3 degree pt temp selfemp ///
	i.class3 i.industry [aw=weightall]
margins jqdec, post
est sto m1
coefplot (m1, label("Life satisfaction")), sort(,desc) legend(pos(6)) ylabel(10 "1" 9 "2" 8 "3" 7 "4" ///
	6 "5" 5 "6" 4 "7" 3 "8" 2 "9" 1 "10")
graph export "$output\gwi_lifesat.png", replace





*********************************
*			Chapter 3			*
*********************************


//Good Work across classes
use "$dir\ses2017.dta", clear

*Average percentile position
graph hbar jqpc lnhourpay_sespc [aw=weightall] if sample==1, over(ns_sec) ytitle("") ///
	legend(order(1 "Mean percentile position - GWI" 2 "Mean percentile position - pay") position(6))
graph export "$output\gwiXclass3.png", replace

*Distribubtion across terciles
tab jqterc, gen(jqterc_)

graph hbar (mean) jqterc_*, over(ns_sec) blabel(bar, size(vsmall) position(inside) ///
	format(%9.2g) ) stack legend(order(3 "Top third" ///
	2 "Middle third" 1 "Bottom third") position(6))
graph export "$output\gwi_groupXclass3.png", replace

*Job quality by class
tabstat jq std_lnhourpay_ses std_security_ses std_learning_ses std_useskills_ses std_variety_ses ///
	std_discret_ses std_demands_ses std_wlb_ses std_rep_ses [aw=weightall], by(ns_sec) format(%9.2f)

*Job quality by class
tabstat jq lnhourpay_ses security_ses learning_ses useskills_ses variety_ses ///
	discret_ses demands_ses wlb_ses rep_ses [aw=weightall], by(ns_sec) format(%9.2f)
	
	
*Within-class inequality
 use "$dir\ses2017.dta", clear
 gen jqp20=.
 gen jqp80=.
 gen jqp80p20=.
 gen payp20=.
 gen payp80=.
 gen payp80payp20=.
foreach i of numlist 1 2 3 4 5 6 7 {
	_pctile jq if ns_sec==`i' & sample==1 [aw=weightall], p(20, 80)
	replace jqp20=`r(r1)' if ns_sec==`i'
	replace jqp80=`r(r2)' if ns_sec==`i'
	replace jqp80p20 = jqp80/jqp20 if ns_sec==`i'
	_pctile lnhourpay if ns_sec==`i' & sample==1 [aw=weightall], p(20, 80)
	replace payp20=`r(r1)' if ns_sec==`i'
	replace payp80=`r(r2)' if ns_sec==`i'
	replace payp80payp20 = payp80/payp20 if ns_sec==`i'
}	

graph hbar jqp80p20 payp80payp20 [aw=weightall], over(ns_sec) legend(order(1 "P80-P20 GWI" ///
	2 "P80-P20 pay") position(6))
graph export "$output\gwi_ineqXclass3.png", replace


*GWI across occupations
use "$dir\ses2017.dta", clear
tab socmaj, gen(socmaj_)
gen one=1
collapse (mean) jq jqpc lnhourpay_sespc lnhourpay_ses ////
	(mean) socmaj satis_ses security_ses learning_ses ///
	useskills_ses variety_ses discret_ses demands_ses wlb_ses rep_ses socmaj_* ///
	(count) one (semean) jqse=jq (semean) jqpcse=jqpc [aw=weightall] if year>=2006, by(rcsoc2000)

sum lnhourpay_ses, d
replace lnhourpay_ses=`r(p99)' if lnhourpay_ses>`r(p99)' & lnhourpay_ses<.
sum jq, d
replace jq=`r(p1)' if jq<`r(p1)'

*Confidence intervals
gen ljq=jq-(1.96*jqse)
gen ujq=jq+(1.96*jqse)
gen ljqpc=jqpc-(1.96*jqpcse)
gen ujqpc=jqpc+(1.96*jqpcse)

twoway (qfit ljq jq, sort) (qfit ujq jq, sort) (scatter jq jq, sort),  xline(50) yline(50)
twoway (qfit ljqpc jqpc, sort) (qfit ujqpc jqpc, sort) (scatter jqpc jqpc, sort),  xline(50) yline(50)

xtile loccdec=ljqpc [aw=one], nq(10)
xtile uoccdec=ujqpc [aw=one], nq(10)
xtile occdec=jqpc [aw=one], nq(10)

xtile loccquint=ljqpc [aw=one], nq(5)
xtile uoccquint=ujqpc [aw=one], nq(5)
xtile occquint=jqpc [aw=one], nq(5)

xtile loccquart=ljqpc [aw=one], nq(4)
xtile uoccquart=ujqpc [aw=one], nq(4)
xtile occquart=jqpc [aw=one], nq(4)

gen class=.
replace class=1 if socmaj_1==1
replace class=1 if socmaj_2==1
replace class=1 if socmaj_3==1

replace class=2 if socmaj_4==1
replace class=2 if socmaj_5==1
replace class=2 if socmaj_6==1

replace class=3 if socmaj_7==1
replace class=3 if socmaj_8==1
replace class=3 if socmaj_9==1


*Occupational GWI by occupational pay - class in terms of SOC
twoway (scatter lnhourpay_ses jq if class==1 & jq>2  [aw=one], msymbol(Oh) msize(vsmall)) ///
	(scatter lnhourpay_ses jq if class==2 & jq>2 [aw=one], msymbol(T) msize(vsmall)) ///
	(scatter lnhourpay_ses jq if class==3 & jq>2  [aw=one], msymbol(Sh) msize(vsmall)) ///
	(lfit lnhourpay_ses jq if jq>2  [aw=one]), legend(order(1 "Managerial & professional" ///
	2 "Intermediate occupations" 3 "Routine and manual") position(6)) ytitle("Mean GWI") ///
	xtitle("Mean log hourly pay")
graph export "$output\gwi_payXocc.png", replace

/*
*Occupational GWI by occupational pay - NS-SEC
twoway (scatter jq lnhourpay_ses if ns_sec_1>.5 & ns_sec_1<., msymbol(Oh)) ///
	(scatter jq lnhourpay_ses  if ns_sec==2, msymbol(Th)) ///
	(scatter jq lnhourpay_ses if ns_sec==3, msymbol(Sh)) ///
	(scatter jq lnhourpay_ses if ns_sec==4, msymbol(X)) ///
	(scatter jq lnhourpay_ses if ns_sec==5 , msymbol(O)) ///
	(scatter jq lnhourpay_ses if ns_sec==6, msymbol(T)) ///
	(scatter jq lnhourpay_ses if ns_sec==7, msymbol(S)) ///
	(lfit jq lnhourpay_ses [aw=one]), legend(order(1 "Managerial & professional" ///
		2 "Intermediate occupations" 3 "Routine and manual") position(6)) ytitle("Mean GWI") ///
	xtitle("Mean log hourly pay")
graph export "$output\gwi_payXocc.png", replace
*/

*Top GWI
xtile group=jq, nq(10) // 10 groups of 20
foreach var of varlist jq jqpc satis_ses lnhourpay_ses security_ses learning_ses useskills_ses variety_ses discret_ses ///
	demands_ses wlb_ses rep_ses {
	gsort -`var'
	gen `var'rank=_n
}
order rcsoc2000 jqpcrank class *_sesrank satis_sesrank
gsort -jqpc
list rcsoc2000 jqpc lnhourpay_sespc class one in 1/20

*Bottom GWI
gsort -jqpc
list rcsoc2000 jqpc lnhourpay_sespc class one if group==1

*Middle GWI
gsort -jqpc
list rcsoc2000 jqpc lnhourpay_sespc class one if group==5 | group==6

*Occupations where occupational GWI-OQ rank > than occupational pay rank
gen diff = lnhourpay_sespc-jqpc
gsort -diff
list rcsoc2000 diff jqpc lnhourpay_sespc one in 1/24

sort diff
list rcsoc2000 diff jqpc lnhourpay_sespc one  in 1/20

*Job quality of exceptional occupations
recode diff (-55.1/-17.2=1 "Interesting") (17.3/50=2 "Mundane") (else=.), gen(clusters)
replace clusters=. if rcsoc2000==8215
replace clusters=. if rcsoc2000==3319
replace clusters=. if rcsoc2000==3411

tabstat jqpc lnhourpay_sespc, by(cluster)

tabstat jq lnhourpay_ses security_ses learning_ses useskills_ses ///
	variety_ses discret_ses demands_ses wlb_ses rep_ses, by(cluster) ///
	columns(statistics)

tabstat jq lnhourpay_ses security_ses learning_ses useskills_ses ///
	variety_ses discret_ses demands_ses wlb_ses rep_ses [aw=one], by(cluster) ///
	columns(statistics)	
	
rename (*) (occ*)
rename (occoccdec occoccquint occoccquart) (occdec occquint occquart)
rename occrcsoc2000 rcsoc2000
save "$output\occqual.dta", replace

*Merge into SES
use "$dir\ses2017.dta", clear
drop occ* _merge_occq
merge m:m rcsoc2000 using "$dir\occqual.dta", generate(_merge_occq)
drop if rcsoc2000==.
compress
save, replace

*Explanatory power of occupation across Good Work dimensions over time
use "$dir\ses2017.dta", clear

foreach var of varlist lnhourpay security_ses learning_ses useskills_ses variety_ses discret_ses ///
	demands_ses wlb_ses rep_ses jq satis_ses {
	gen `var'R2_occ=.
	gen `var'R2_dem=.
}
capture noisily foreach var of varlist lnhourpay security_ses learning_ses useskills_ses variety_ses discret_ses ///
	demands_ses wlb_ses rep_ses jq satis_ses {
	capture noisily foreach num of numlist 1986 1992 1997 2001 2006 2012 2017 {
		capture noisily areg `var' [aw=weightall] if year==`num', absorb(rcsoc2000)
		capture noisily replace `var'R2_occ = `e(r2)' if year==`num'
		capture noisily reg `var' sex i.agecat ethnic kids i.region degree pt selfemp ///
		i.industry [aw=weightall] if year==`num'
		capture noisily replace `var'R2_dem = `e(r2)' if year==`num'
	}
}

twoway (lfit lnhourpayR2_occ year, sort) (scatter lnhourpayR2_occ year, sort) ///
	/* (line lnhourpayR2_dem year, sort) */, legend(off) xtitle("") ytitle("") ///
	xlabel(1986 1992 1997 2001 2006 2012 2017, angle(45)) title("Log hourly pay")
graph save "$output\g1", replace

twoway (lfit security_sesR2_occ year) (scatter security_sesR2_occ year) ///
	/*(line security_sesR2_dem year, sort) */, legend(off) xtitle("") ytitle("") ///
	xlabel(1986 1992 1997 2001 2006 2012 2017 , angle(45)) title("Job security") legend(off)
graph save "$output\g2", replace

twoway (lfit learning_sesR2_occ year if year>=1992, sort) (scatter learning_sesR2_occ year ///
	if year>=1992, sort) /*(line learning_sesR2_dem year if year>=1992, sort) */, legend(off) xtitle("") ytitle("") ///
	xlabel(1986 1992 1997 2001 2006 2012 2017, angle(45)) title("Continuous learning")
graph save "$output\g3", replace

twoway (lfit useskills_sesR2_occ year if year>=2001, sort) (scatter useskills_sesR2_occ year ///
	if year>=2001, sort)/*(line  useskills_sesR2_dem year if year>=2001, sort) */, legend(off) xtitle("") ytitle("") ///
	xlabel(1986 1992 1997 2001 2006 2012 2017, angle(45)) title("Skill-use opportunities")
graph save "$output\g4", replace

twoway (lfit variety_sesR2_occ year if year>=1997, sort) (scatter variety_sesR2_occ year if year>=1997, sort) ///
 /*(line  variety_sesR2_dem year if year>=1997, sort) */, legend(off) xtitle("") ytitle("") ///
	xlabel(1986 1992 1997 2001 2006 2012 2017, angle(45)) title("Task variety")
graph save "$output\g5", replace

twoway (lfit discret_sesR2_occ year if year>=1992, sort) (scatter discret_sesR2_occ year if year>=1992, sort) ///
	/*(line  discret_sesR2_dem year if year>=1992, sort) */, legend(off) xtitle("") ytitle("") ///
	xlabel(1986 1992 1997 2001 2006 2012 2017, angle(45)) title("Task discretion")
graph save "$output\g6", replace

twoway (lfit demands_sesR2_occ year if year>=1992, sort) (scatter demands_sesR2_occ year if year>=1992, sort)  ///
	/*(line demands_sesR2_dem year if year>=1992, sort) */, legend(off) xtitle("") ytitle("") ///
	xlabel(1986 1992 1997 2001 2006 2012 2017, angle(45))  title("Job demands")
graph save "$output\g7", replace
 
twoway (lfit wlb_sesR2_occ year if year>=2006, sort) (scatter wlb_sesR2_occ year if year>=2006, sort) ///
	/*(line wlb_sesR2_dem year if year>=2006, sort) */, legend(off) xtitle("") ytitle("") ///
	xlabel(1986 1992 1997 2001 2006 2012 2017, angle(45)) title("Control over work time")
graph save "$output\g8", replace
 
twoway (lfit rep_sesR2_occ year, sort) (scatter rep_sesR2_occ year, sort) ///
	/*(line rep_sesR2_dem year, sort) */, legend(off) xtitle("") ytitle("") ///
	xlabel(1986 1992 1997 2001 2006 2012 2017, angle(45)) title("Participation opportunities")
graph save "$output\g9", replace

twoway (lfit jqR2_occ year if year>=2006, sort) (scatter jqR2_occ year if year>=2006, sort) ///
	/* (line jqR2_dem year if year>=1992, sort) */, legend(off) xtitle("") ytitle("") ///
	xlabel(1986 1992 1997 2001 2006 2012 2017, angle(45)) title("GWI")
graph save "$output\g10", replace

twoway (lfit satis_sesR2_occ year if year>=1992, sort) (scatter satis_sesR2_occ year if year>=1992, sort) ///
	/* (line satis_sesR2_dem year if year>=1992, sort) */, legend(off) xtitle("") ytitle("") ///
	xlabel(1986 1992 1997 2001 2006 2012 2017, angle(45)) title("Job satisfaction")
graph save "$output\g11", replace

graph combine "$output\g1.gph" "$output\g2.gph" "$output\g3.gph" "$output\g4.gph" ///
	"$output\g5.gph" "$output\g6.gph" "$output\g7.gph" "$output\g8" "$output\g9.gph"
graph export "$output\occR2_1.png", replace
	
graph combine "$output\g10.gph" "$output\g11.gph" 
graph export "$output\occR2_2.png", replace	




*Comparison of the job-level GWI with occupation-level GWI
use "$dir\ses2017.dta", clear

pwcorr occlnhourpay_ses lnhourpay
pwcorr occsecurity_ses security_ses 
pwcorr occlearning_ses learning_ses
pwcorr occuseskills_ses useskills_ses 
pwcorr occvariety_ses variety_ses 
pwcorr occdiscret_ses discret_ses 
pwcorr occdemands_ses demands_ses 
pwcorr occwlb_ses wlb_ses 
pwcorr occrep_ses rep_ses 
pwcorr occjq jq 
pwcorr occsatis_ses satis_ses

save, replace

*Are the highest quality occupations the most satisfied?
use "$output\occqual.dta", clear
drop if occjq<2
/*
twoway (scatter satis_ses jq if class==1 [aw=one], msymbol(Oh) msize(vsmall)) ///
	(scatter satis_ses jq if class==2 [aw=one], msymbol(T) msize(vsmall)) ///
	(scatter satis_ses jq if class==3 [aw=one], msymbol(Sh) msize(vsmall)) ///
	(lfit satis_ses jq [aw=one]), legend(order(1 "Managerial & professional" ///
	2 "Intermediate occupations" 3 "Routine and manual") position(6)) xtitle("Mean GWI") ///
	ytitle("Mean satisfaction")
graph export "$output\gwi_satisXocc.png", replace
*/
twoway (scatter occsatis_ses occjq if occquint==5 [aw=occone], msymbol(Oh) msize(vsmall)) ///
	(scatter occsatis_ses occjq if occquint==4 [aw=occone], msymbol(T) msize(vsmall)) ///
	(scatter occsatis_ses occjq if occquint==3 [aw=occone], msymbol(Sh) msize(vsmall)) ///
	(scatter occsatis_ses occjq if occquint==2 [aw=occone], msymbol(O) msize(vsmall)) ///
	(scatter occsatis_ses occjq if occquint==1 [aw=occone], msymbol(Th) msize(vsmall)) ///
	(lfit occsatis_ses occjq [aw=occone]), legend(order(1 "Top 20%" ///
	2 "Upper middle 20%" 3 "Middle 20%" 4 "Lower middle 20%" 5 "Bottom 20%") position(6)) xtitle("Mean GWI") ///
	ytitle("Mean satisfaction")


	
	
*********************************
*			Chapter 4			*
*********************************

use "$dir\ses2017.dta", clear
drop period*

recode year (1986/1992=1 "1986/92") (else=0), gen(period1)
recode year (2001/2006=1 "2001/06") (else=0), gen(period2)
recode year (2012/2017=1 "2012/17") (else=0), gen(period3)
/*
recode year (1986=1 "1986") (else=0), gen(period1)
recode year (2001=1 "2001") (else=0), gen(period2)
recode year (2017=1 "2017") (else=0), gen(period3)
*/

save, replace 

use "$dir\ses2017.dta", clear
gen one=1
gen period=1
collapse (mean) satis_ses sat_ses dissat_ses lnhourpay_ses security_ses useskills_ses ///
	learning_ses variety_ses discret_ses demands_ses wlb_ses rep_ses hourpay_ses jqpc ///
	jq period (count) one if period1==1, by(rcsoc2000)
save "$dir\occ_p1.dta", replace

use "$dir\ses2017.dta", clear
gen one=1
gen period=2
collapse (mean) satis_ses sat_ses dissat_ses lnhourpay_ses security_ses useskills_ses ///
	learning_ses variety_ses discret_ses demands_ses wlb_ses rep_ses hourpay_ses jqpc ///
	jq period (count) one if period2==1, by(rcsoc2000)
save "$dir\occ_p2.dta", replace

use "$dir\ses2017.dta", clear
gen one=1
gen period=3
collapse (mean) satis_ses sat_ses dissat_ses lnhourpay_ses security_ses useskills_ses ///
	learning_ses variety_ses discret_ses demands_ses wlb_ses rep_ses hourpay_ses jqpc ///
	jq period (count) one if period3==1, by(rcsoc2000)
save "$dir\occ_p3.dta", replace

use "$dir\occ_p1.dta", clear
append using "$dir\occ_p2.dta"
append using "$dir\occ_p3.dta"
save "$dir\occ.dta", replace

erase "$dir\occ_p1.dta"
erase "$dir\occ_p2.dta"
erase "$dir\occ_p3.dta"

tsset rcsoc2000 period
drop if rcsoc2000==.
tsfill, full // fill in missing periods
save, replace

bys period: egen periodN = total(one)
gen occshare_temp=one/periodN

bys rcsoc2000: ipolate occshare_temp period, gen(occshare_temp_i) epolate
replace occshare_temp_i=abs(occshare_temp_i)

bys period: egen periodtotal = total(occshare_temp_i)
gen occshare_i=occshare_temp_i/periodtotal

foreach var of varlist satis_ses lnhourpay_ses security_ses useskills_ses ///
	learning_ses variety_ses discret_ses demands_ses wlb_ses rep_ses jq {
	bys rcsoc2000: ipolate `var' period, gen(`var'_i) epolate
	replace `var'_i=`var' if `var'_i==.
	gsort rcsoc2000 -period
	bys rcsoc2000: carryforward `var'_i, replace
	gsort rcsoc2000 period
	bys rcsoc2000: carryforward `var'_i, replace
}

foreach var of varlist satis_ses_i-rep_ses_i jq_i {
	xtile `var'_quint_p1=`var' [aw=occshare_i] if period==1, nq(5)
	xtile `var'_quint_p2=`var' [aw=occshare_i] if period==2, nq(5)
	xtile `var'_quint_p3=`var' [aw=occshare_i] if period==3, nq(5)
	gen `var'_quint =.
	replace `var'_quint=`var'_quint_p1 if period==1
	replace `var'_quint=`var'_quint_p2 if period==2
	replace `var'_quint=`var'_quint_p3 if period==3
}

gsort rcsoc2000 -period
bys rcsoc2000: carryforward *_quint *_quint_p* occshare_i, replace
sort rcsoc2000 period
bys rcsoc2000: carryforward *_quint *_quint_p* occshare_i, replace

gen occshare_p1=.
gen occshare_p2=.
gen occshare_p3=.
replace occshare_p1=occshare_i if period==1
replace occshare_p2=occshare_i if period==2
replace occshare_p3=occshare_i if period==3

sort rcsoc2000 period
bys rcsoc2000: carryforward occshare_p*, replace
gsort rcsoc2000 -period
by rcsoc2000: carryforward occshare_p*, replace

recode rcsoc2000 (1111=0.2581608) (1112=0.2726092) (1113=0.2849461) (1114=0.2662018) (1121=0.3064057) (1122=0.2933409) (1123=0.2667893) (1131=0.3046549) (1132=0.3251788) (1133=0.295945) (1134=0.2588611) (1135=0.2917179) (1136=0.2465227) (1137=0.2417762) (1141=0.2674718) (1142=0.4035945) (1151=0.3219806) (1152=0.4311619) (1161=0.3102954) (1162=0.3657039) (1163=0.3832033) (1171=0.2311414) (1172=0.2303624) (1173=0.2484781) (1174=0.3281445) (1181=0.2425849) (1182=0.2437677) (1183=0.3061108) (1184=0.2446313) (1185=0.3024002) (1211=0.3609945) (1212=0.2422984) (1219=0.3574731) (1221=0.370072) (1222=0.3839789) (1223=0.4120885) (1224=0.4186407) (1225=0.3157885) (1226=0.3111629) (1231=0.3145894) (1232=0.3761468) (1233=0.3692891) (1234=0.4325971) (1235=0.3022695) (1239=0.3075603) (1259=0.3023885) (2111=0.2594658) (2112=0.22946) (2113=0.2213477) (2121=0.2542074) (2122=0.2925112) (2123=0.2953982) (2124=0.2873854) (2125=0.3089381) (2126=0.278174) (2127=0.3159652) (2128=0.3280852) (2129=0.2877293) (2131=0.2802373) (2132=0.2816372) (2211=0.1818775) (2212=0.2086692) (2213=0.241659) (2214=0.2660837) (2215=0.2078252) (2216=0.2350133) (2311=0.2028237) (2312=0.2304858) (2313=0.225098) (2314=0.2062203) (2315=0.2192711) (2316=0.2395216) (2317=0.2095718) (2319=0.2808044) (2321=0.2237154) (2322=0.2355755) (2329=0.2585294) (2411=0.2318864) (2419=0.2502778) (2421=0.259902) (2422=0.2610498) (2423=0.2653944) (2431=0.2251864) (2432=0.2293031) (2433=0.2737153) (2434=0.246333) (2441=0.242389) (2442=0.2620037) (2443=0.2563252) (2444=0.2440153) (2451=0.267323) (2452=0.2491283) (3111=0.3738083) (3112=0.403088) (3113=0.3922061) (3114=0.3770692) (3115=0.4172726) (3119=0.4062359) (3121=0.3367356) (3122=0.3867362) (3123=0.3361362) (3131=0.3698294) (3132=0.3920656) (3211=0.2467833) (3212=0.2405245) (3213=0.2794244) (3214=0.2119212) (3215=0.2537093) (3216=0.4534116) (3217=0.5185792) (3218=0.3407269) (3221=0.2123019) (3222=0.2155711) (3223=0.224742) (3229=0.3128114) (3231=0.368814) (3232=0.3697746) (3311=0.3255183) (3312=0.3347557) (3313=0.3491991) (3314=0.3932092) (3319=0.3432023) (3411=0.3449304) (3412=0.3481487) (3413=0.4444624) (3414=0.4810052) (3415=0.33352) (3416=0.2948083) (3421=0.3513526) (3422=0.3868628) (3431=0.2530358) (3432=0.3039326) (3433=0.279233) (3434=0.3671707) (3441=0.4981657) (3442=0.443357) (3443=0.4590026) (3449=0.4456062) (3511=0.3574521) (3512=0.2779576) (3513=0.3302692) (3514=0.5704152) (3520=0.3864861) (3531=0.3985263) (3532=0.3558601) (3533=0.4193203) (3534=0.3654816) (3535=0.3466047) (3536=0.4070734) (3537=0.3827546) (3539=0.3673661) (3541=0.4148695) (3542=0.4826038) (3543=0.4299183) (3544=0.4505619) (3551=0.2431829) (3552=0.3445409) (3561=0.3482993) (3562=0.4138167) (3563=0.3728027) (3564=0.373921) (3565=0.3361362) (3566=0.3361362) (3567=0.3443569) (3568=0.2562719) (4111=0.3920716) (4112=0.5085933) (4113=0.5102063) (4114=0.5178547) (4121=0.594924) (4122=0.5617011) (4123=0.5865058) (4131=0.5533987) (4132=0.575932) (4133=0.5830501) (4134=0.5302914) (4135=0.5237474) (4136=0.5423912) (4137=0.5004574) (4141=0.5409795) (4142=0.4634227) (4150=0.5804268) (4211=0.5566047) (4212=0.6157218) (4213=0.5470932) (4214=0.5754908) (4215=0.5822443) (4216=0.6183278) (4217=0.5812564) (5111=0.3686437) (5112=0.3840814) (5113=0.3212011) (5119=0.3965298) (5211=0.5552773) (5212=0.5383683) (5213=0.5400346) (5214=0.5358027) (5215=0.5499007) (5216=0.5251331) (5221=0.542547) (5222=0.5256711) (5223=0.5105528) (5224=0.5030535) (5231=0.5555263) (5232=0.5646709) (5233=0.5558861) (5234=0.5733811) (5241=0.5061499) (5242=0.4891069) (5243=0.4902419) (5244=0.4901354) (5245=0.450159) (5249=0.4931775) (5311=0.5172196) (5312=0.5393192) (5313=0.5394578) (5314=0.5192682) (5315=0.5310104) (5316=0.5488032) (5319=0.4945931) (5321=0.5456405) (5322=0.5484999) (5323=0.5418298) (5411=0.5753563) (5412=0.570606) (5413=0.557421) (5414=0.5712142) (5419=0.5605032) (5421=0.5208725) (5422=0.5049711) (5423=0.5529364) (5424=0.5048066) (5431=0.5848174) (5432=0.5850647) (5433=0.6025672) (5434=0.5458581) (5491=0.5451392) (5492=0.5294774) (5493=0.5260563) (5494=0.5260563) (5495=0.5260563) (5496=0.6361198) (5499=0.5260563) (6111=0.4889063) (6112=0.4569984) (6113=0.5257203) (6114=0.4519922) (6115=0.5251674) (6121=0.5225329) (6122=0.5577531) (6123=0.5212546) (6124=0.483016) (6131=0.5115579) (6139=0.5504099) (6211=0.5508912) (6212=0.519695) (6213=0.5255076) (6214=0.4936788) (6215=0.4580479) (6219=0.5048795) (6221=0.587923) (6222=0.5894292) (6231=0.5593973) (6232=0.464365) (6291=0.4994896) (6292=0.4952919) (7111=0.6219541) (7112=0.6426934) (7113=0.5662408) (7121=0.5256835) (7122=0.5281748) (7123=0.5646247) (7124=0.5596544) (7125=0.5440468) (7129=0.5019327) (7211=0.5367758) (7212=0.5403059) (8111=0.6496061) (8112=0.6313063) (8113=0.6460423) (8114=0.6054897) (8115=0.6346292) (8116=0.6125605) (8117=0.6042938) (8118=0.6200386) (8119=0.6276003) (8121=0.6344422) (8122=0.5949568) (8123=0.5719529) (8124=0.5585211) (8125=0.5937732) (8126=0.5592193) (8129=0.6300017) (8131=0.6351467) (8132=0.6166336) (8133=0.5973946) (8134=0.6716024) (8135=0.6806983) (8136=0.5712142) (8137=0.686432) (8138=0.3828478) (8139=0.6184285) (8141=0.6043669) (8142=0.5819793) (8143=0.5556854) (8149=0.5305516) (8211=0.621894) (8212=0.6551384) (8213=0.6102553) (8214=0.6340832) (8215=0.519453) (8216=0.541203) (8217=0.5560023) (8218=0.5700023) (8219=0.5628756) (8221=0.6126325) (8222=0.6438601) (8223=0.6575828) (8229=0.6146629) (9111=0.690459) (9112=0.5835208) (9119=0.6435258) (9121=0.6248137) (9129=0.5784469) (9131=0.6403202) (9132=0.6404657) (9133=0.5977209) (9134=0.672187) (9139=0.6398712) (9141=0.634096) (9149=0.6336218) (9211=0.6051857) (9219=0.6528759) (9221=0.5577179) (9222=0.6532331) (9223=0.6915425) (9224=0.7279023) (9225=0.7064934) (9226=0.6654283) (9229=0.6493921) (9231=0.6237135) (9232=0.5859095) (9233=0.6682509) (9234=0.6482509) (9235=0.595548) (9239=0.6247479) (9241=0.5685082) (9242=0.5717606) (9243=0.6370677) (9244=0.6370677) (9245=0.5717606) (9249=0.5858198) (9251=0.7147729) (9259=0.7055364) ///
	,gen(auto)
xtile auto_quint_p1=auto [aw=occshare_i] if period==1, nq(5)
xtile auto_quint_p2=auto [aw=occshare_i] if period==2, nq(5)
xtile auto_quint_p3=auto [aw=occshare_i] if period==3, nq(5)
gen auto_quint=.
replace auto_quint=auto_quint_p1 if period==1
replace auto_quint=auto_quint_p2 if period==2
replace auto_quint=auto_quint_p3 if period==3
sort rcsoc2000 period
bys rcsoc2000: carryforward auto_quint auto_quint_p*, replace
gsort rcsoc2000 -period
by rcsoc2000: carryforward auto_quint auto_quint_p*, replace

rename *ses_i_* **
rename occshare_i occshare

save "$dir\ch4.dta", replace

*Changing occupational structure by different hierarchies
use "$dir\ch4.dta", clear

foreach var in satis_quint lnhourpay_quint security_quint ///
	useskills_quint learning_quint variety_quint discret_quint ///
	demands_quint wlb_quint rep_quint jq_i_quint {
	use "$dir\ch4.dta", clear
	collapse (sum) occshare, by(`var'_p2 period)
	reshape wide occshare , i(`var'_p2) j(period)

	gen dp3_p1 = ((occshare3-occshare1)/occshare1)*100
	gen dp3_p2 = ((occshare3-occshare2)/occshare1)*100
	gen dp2_p1 = ((occshare2-occshare1)/occshare1)*100
	save "$output\`var'.dta", replace
}

*Pay quintiles
use "$output\lnhourpay_quint.dta", clear
graph bar (sum) dp3_p1 dp2_p1 dp3_p2, over(lnhourpay_quint_p2) legend(order(1 "1986/92 to 2012/17" ///
		2 "1986/92 to 2001/06" 3 "2001/06 to 2012/17") position(6)) ///
		/*yscale(range(-40 40)) ylabel(-40(20)60) */ ytitle("% change in employment") ///
		title("Occupational pay quintiles")
graph save "$output\lnhourpay.gph", replace
	
*GWI quintiles
use "$output\jq_i_quint.dta", clear
graph bar (sum) dp3_p1 dp2_p1 dp3_p2, over(jq_i_quint_p2) legend(order(1 "1986/92 to 2012/17" ///
		2 "1986/92 to 2001/06" 3 "2001/06 to 2012/17") position(6)) ///
		/*yscale(range(-40 40)) ylabel(-40(20)60) */ ytitle("% change in employment") ///
		title("Occupational quality quintiles")
graph save "$output\jq_i.gph", replace

grc1leg "$output\lnhourpay.gph" "$output\jq_i.gph", xcommon ycommon
graph export "$output\polarization1.png", replace

*Security
use "$output\security_quint.dta", clear
graph bar (sum) dp3_p1, over(security_quint_p2) legend(off) ///
		/*yscale(range(-40 40)) ylabel(-40(20)60) */ ytitle("% change in employment") ///
		title("Occupational security quintiles")
graph save "$output\security.gph", replace

*Learning
use "$output\learning_quint.dta", clear
graph bar (sum) dp3_p1, over(learning_quint_p2) legend(off) ///
		/*yscale(range(-40 40)) ylabel(-40(20)60) */ ytitle("% change in employment") ///
		title("Occupational learning quintiles")
graph save "$output\learning.gph", replace

*Skill-use
use "$output\useskills_quint.dta", clear
graph bar (sum) dp3_p1, over(useskills_quint_p2) legend(off) ///
		/*yscale(range(-40 40)) ylabel(-40(20)60) */ ytitle("% change in employment") ///
		title("Occupational skill-use quintiles")
graph save "$output\skilluse.gph", replace

*Variety
use "$output\variety_quint.dta", clear
graph bar (sum) dp3_p1, over(variety_quint_p2) legend(off) ///
		/*yscale(range(-40 40)) ylabel(-40(20)60) */ ytitle("% change in employment") ///
		title("Occupational task variety quintiles")
graph save "$output\variety.gph", replace

*Discretion
use "$output\discret_quint.dta", clear
graph bar (sum) dp3_p1, over(discret_quint_p2) legend(off) ///
		/*yscale(range(-40 40)) ylabel(-40(20)60) */ ytitle("% change in employment") ///
		title("Occupational task discretion quintiles")
graph save "$output\discret.gph", replace

*Job demands
use "$output\demands_quint.dta", clear
graph bar (sum) dp3_p1, over(demands_quint_p2) legend(off) ///
		/*yscale(range(-40 40)) ylabel(-40(20)60) */ ytitle("% change in employment") ///
		title("Occupational demands quintiles")
graph save "$output\demands.gph", replace

*Control over work time
use "$output\wlb_quint.dta", clear
graph bar (sum) dp3_p1, over(wlb_quint_p2) legend(off) ///
		/*yscale(range(-40 40)) ylabel(-40(20)60) */ ytitle("% change in employment") ///
		title("Occupational work time control quintiles")
graph save "$output\wlb.gph", replace

*Participation
use "$output\rep_quint.dta", clear
graph bar (sum) dp3_p1, over(rep_quint_p2) legend(off) ///
		/*yscale(range(-40 40)) ylabel(-40(20)60) */ ytitle("% change in employment") ///
		title("Occupational participation quintiles")
graph save "$output\rep.gph", replace

*Satisfaction
use "$output\satis_quint.dta", clear
graph bar (sum) dp3_p1, over(satis_quint_p2) legend(off) ///
		/*yscale(range(-40 40)) ylabel(-40(20)60) */ ytitle("% change in employment") ///
		title("Occupational satisfaction quintiles")
graph save "$output\satis.gph", replace

graph combine "$output\security.gph" "$output\learning.gph" "$output\variety.gph" "$output\skilluse.gph", ///
	row(2) col(2) 
graph export "$output\polarization2.png", replace

graph combine "$output\discret.gph" "$output\demands.gph" "$output\wlb.gph" "$output\rep.gph", ///
	row(2) col(2) 
graph export "$output\polarization3.png", replace


*Changing class structure
use "$dir\ses2017.dta", clear
tab ns_sec_soc, gen(ns_sec_soc_)
graph bar ns_sec_soc_6 ns_sec_soc_5 ns_sec_soc_4 ns_sec_soc_3 ns_sec_soc_2 ns_sec_soc_1 ///
	if year==1986 | year==2001 | year==2017, over(year) stack ///
	legend(position(6) order(6 "Higher managerial & professional" 5 "Lower managerial & professional" ///
	4 "Intermediate occupations" 3 "Lower supervisory & technical" 2 "Semi-routine occupations" 1 "Routine occupations"))
graph export "$output\class_structure.png", replace

*Automation probabiilty
use "$dir\ch4.dta", clear
rename *_ses* **
twoway (scatter auto lnhourpay_i if period==3 [aw=occshare], mcolor(%15)) ///
	(lpoly auto lnhourpay_i if period==3 [aw=occshare]) ///
	, legend(off) ytitle("Automation probability") xtitle("Mean log hourly pay") legend(off) title("By occupational pay")
graph save "$output\g1.gph", replace

twoway (scatter auto jq_i if period==3 [aw=occshare], mcolor(%15)) ///
	(lpoly auto jq_i if period==3 [aw=occshare]) ///
	, legend(off) ytitle("Automation probability") xtitle("Mean log hourly pay") legend(off) title("By occupational quality")
graph save "$output\g2.gph", replace

graph combine "$output\g1.gph" "$output\g2.gph"
graph export "$output\automation.png", replace

*Automation potential structure	
use "$dir\ch4.dta", clear
collapse (sum) occshare lnhourpay_ses_i security_ses_i useskills_ses_i learning_ses_i variety_ses_i 		discret_ses_i demands_ses_i wlb_ses_i rep_ses_i jq_i, by(auto_quint_p3 period)

reshape wide occshare lnhourpay_ses_i security_ses_i useskills_ses_i learning_ses_i variety_ses_i discret_ses_i 	demands_ses_i wlb_ses_i rep_ses_i jq_i, i(auto_quint_p3) j(period)

foreach var of newlist occshare lnhourpay_ses_i security_ses_i useskills_ses_i learning_ses_i variety_ses_i 		discret_ses_i demands_ses_i wlb_ses_i rep_ses_i jq_i {
	gen d`var'_p3_p1 = ((`var'3-`var'1)/`var'1)*100
	gen d`var'_p3_p2 = ((`var'3-`var'2)/`var'1)*100
	gen d`var'_p2_p1 = ((`var'2-`var'1)/`var'1)*100
}

graph bar (sum) doccshare_p3_p1 , over(auto_quint_p3) legend(order(1 "1986/92 to 2012/17" ///
	2 "1986/92 to 2001/06" 3 "2001/06 to 2012/17") position(6)) title("Occupational automobility quintiles") ///
	 ytitle("% change in employment")

graph bar (sum) dlnhourpay_ses_i_p3_p1 , over(auto_quint_p3) legend(order(1 "1986/92 to 2012/17" ///
	2 "1986/92 to 2001/06" 3 "2001/06 to 2012/17") position(6)) title("Occupational automobility quintiles") ///
	 ytitle("% change in pay")
	 
graph bar (sum) dvariety_ses_i_p3_p1 , over(auto_quint_p3) legend(order(1 "1986/92 to 2012/17" ///
	2 "1986/92 to 2001/06" 3 "2001/06 to 2012/17") position(6)) title("Occupational automobility quintiles") ///
	 ytitle("% change in task variety")
	 
graph bar (sum) ddiscret_ses_i_p3_p1 , over(auto_quint_p3) legend(order(1 "1986/92 to 2012/17" ///
	2 "1986/92 to 2001/06" 3 "2001/06 to 2012/17") position(6)) title("Occupational automobility quintiles") ///
	 ytitle("% change in task discretion")	 

graph bar (sum) ddemands_ses_i_p3_p1 , over(auto_quint_p3) legend(order(1 "1986/92 to 2012/17" ///
	2 "1986/92 to 2001/06" 3 "2001/06 to 2012/17") position(6)) title("Occupational automobility quintiles") ///
	 ytitle("% change in demands")	  
	 
	 
*Changing nature of job quality across the occupational strucure
use "$dir\ses2017.dta", clear
foreach var of varlist lnhourpay_ses security_ses learning_ses useskills_ses variety_ses discret_ses ///
	demands_ses wlb_ses rep_ses satis_ses {
	graph bar `var' [aw=weightall], over(year, label(angle(45))) by(occquint, total note("")) ytitle("")
	graph save "$output\oqXyear_`var'.gph", replace
}
	
graph combine "$output\oqXyear_lnhourpay_ses.gph", title("Log hourly pay")
graph save "$output\oqXyear_lnhourpay_ses.gph", replace

graph combine "$output\oqXyear_security_ses.gph", title("Job security")
graph save "$output\oqXyear_security_ses.gph", replace

graph combine "$output\oqXyear_learning_ses.gph", title("Learning")
graph save "$output\oqXyear_learning_ses.gph", replace

graph combine "$output\oqXyear_useskills_ses.gph", title("Skill-use opportunities")
graph save "$output\oqXyear_useskills_ses.gph", replace

graph combine "$output\oqXyear_variety_ses.gph", title("Task variety")
graph save "$output\oqXyear_variety_ses.gph", replace

graph combine "$output\oqXyear_discret_ses.gph", title("Task discretion")
graph save "$output\oqXyear_discret_ses.gph", replace

graph combine "$output\oqXyear_demands_ses.gph", title("Job demands")
graph save "$output\oqXyear_demands_ses.gph", replace

graph combine "$output\oqXyear_wlb_ses.gph", title("Control over work time")
graph save "$output\oqXyear_wlb_ses.gph", replace

graph combine "$output\oqXyear_rep_ses.gph", title("Participation opportunities")
graph save "$output\oqXyear_rep_ses.gph", replace

graph combine "$output\oqXyear_satis_ses.gph", title("Job satisfaction")
graph save "$output\oqXyear_satis_ses.gph", replace

graph combine "$output\oqXyear_lnhourpay_ses.gph" "$output\oqXyear_security_ses.gph" ///
	"$output\oqXyear_learning_ses.gph" "$output\oqXyear_useskills_ses.gph" ///
	"$output\oqXyear_variety_ses.gph" "$output\oqXyear_discret_ses.gph" ///
	, row(2) ycommon altshrink
graph export "$output\nature1.png", replace

graph combine "$output\oqXyear_demands_ses.gph" "$output\oqXyear_wlb_ses.gph" "$output\oqXyear_rep_ses.gph" ///
	"$output\oqXyear_useskills_ses.gph" "$output\oqXyear_variety_ses.gph" "$output\oqXyear_discret_ses.gph" ///
	, row(2) ycommon altshrink
graph export "$output\nature2.png", replace
